Change log
==========

0.4
---

* Added grouping of fields into field sets
* Added conditionally revealing sub-fields inside choice fields

0.3
---

* Minor accessibility and visual improvements

0.2
---

* Added form and widget HTML creation to match GOV.UK styles
* Added gettext message compilation

0.1
---

* Initial version, includes some bare-bones form fields
